## Usage

```js
var tree = require('base-fs-tree');
```

### gulp plugin example

The following examples will work with [base-fs][], [gulp][], [verb][], [assemble][], [generate][], [update][] or any other application that supports vinyl streams.

```js
var tree = require('base-fs-tree');
var gulp = require('gulp');

gulp.task('default', function(cb) {
  return gulp.src('some-files/**/*.*')
    .pipe(tree.create())
    .pipe(gulp.dest('trees'))
});
```

**Get files before they're modified**

If you want to create a tree from the _original_ unmodified source file paths, use `.capture()` first thing in the stream:

```js
var tree = require('base-fs-tree');
var gulp = require('gulp');

gulp.task('default', function(cb) {
  return gulp.src('some-files/**/*.*')
    .pipe(tree.capture()) //<= capture files

    // gulp plugin pipeline
    .pipe(otherPlugins())
    .pipe(gulp.dest('dist')) 

    .pipe(tree.create()) //<= create tree
    .pipe(gulp.dest('trees'))
});
```

### Command line tips

You can conditionally generate trees using a command line flag, like `--tree`.

```js
var tree = require('base-fs-tree');
var gulp = require('gulp');
var argv = require('yargs-parser')(process.argv.slice(2), {
  default: {tree: false}
});

gulp.task('default', function(cb) {
  return gulp.src('some-files/**/*.*')
    .pipe(tree.create(argv))
    .pipe(gulp.dest('trees'))
});
```

### base plugin example

This can also be used as a _non-pipeline_ plugin with [base][] applications. It works by adding `.preWrite` middleware and a `taskEnd` listener, so that anytime `taskEnd` is emitted, a tree will be automatically generates.

This can be useful when you want to automatically generate trees for all tasks in a [generate][] generator, for example.

```js
var tree = require('base-fs-tree');
var vfs = require('base-fs');
var Base = require('base');
var base = new Base();
base.use(vfs());
base.use(tree());

app.task('default', function(cb) {
  app.src('some-files/**/*.*')
    .pipe(app.dest('trees'))
    .on('end', function() {
      // emit `taskEnd` with the name of the task
      app.emit('taskEnd', 'default');
      cb();
    });
});
```

[assemble]: https://github.com/assemble/assemble
[base-fs]: https://github.com/node-base/base-fs
[base]: https://github.com/node-base/base
[generate]: https://github.com/generate/generate
[gulp]: http://gulpjs.com
[update]: https://github.com/update/update
[verb]: https://github.com/verbose/verb